<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
    xmlns:didl="urn:mpeg:mpeg21:2002:02-DIDL-NS" xmlns:dii="urn:mpeg:mpeg21:2002:01-DII-NS"
    xmlns:dip="urn:mpeg:mpeg21:2002:01-DIP-NS" xmlns:dcterms="http://purl.org/dc/terms/"
    xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
    xsi:schemaLocation="
    urn:mpeg:mpeg21:2002:02-DIDL-NS 
    didl.xsd 
    
    urn:mpeg:mpeg21:2002:01-DII-NS
    http://standards.iso.org/ittf/PubliclyAvailableStandards/MPEG-21_schema_files/dii.xsd/dii.xsd
    
    urn:mpeg:mpeg21:2005:01-DIP-NS
    http://standards.iso.org/ittf/PubliclyAvailableStandards/MPEG-21_schema_files/dip/dip.xsd">

    <xsl:template match="/">
        <html>
            <head>
                <LINK REL="stylesheet" TYPE="text/css" HREF="DIDL_Document_Style.css"/>
            </head>
            <body>
                <h1>DIDL document</h1>
                <xsl:for-each select="//didl:DIDL/didl:Item">
                    <h2>Information entity</h2>
                        <b>Main Identifier: <xsl:call-template name="PersistentIdentifier"/></b>; 
                        <i>(Refer to this Identifier if you want to refer to the entire work.)</i>
                        <br/>

                        <xsl:if test="didl:Component"> Other representations then DIDL document for
                            the Information entity: <br/>
                            <xsl:for-each select="self::didl:Component">
                                <xsl:value-of select="didl:Resource/attribute::ref"/>
                            </xsl:for-each>
                        </xsl:if>

                    <br/>
                    <h3>Object Items</h3>
                    <i>Refer to these Identifiers if you want to refer to a part of the information, click on a representatien to download the information in a format you want.</i>
                    <ul>
                        <xsl:for-each select="didl:Item">
                            <xsl:if
                                test="didl:Descriptor/didl:Statement/dip:ObjectType='info:eu-repo/semantics/hasResourceLocation'">
                                <li><b>Identifier: <xsl:call-template name="PersistentIdentifier"/>
                                    </b> has representation: <xsl:call-template
                                        name="ResourceExtractor"/> </li>
                            </xsl:if>
                        </xsl:for-each>
                    </ul>
                    <h3>Metadata</h3>
                    <xsl:for-each select="didl:Item">
                        <xsl:call-template name="MetadataFormatter"/>
                    </xsl:for-each>
                        

<xsl:for-each select="didl:Item">
                            <xsl:if
                                test="didl:Descriptor/didl:Statement/dip:ObjectType='info:eu-repo/semantics/hasIntermediatePage'"
                                > 
                   <h3>Extra services</h3>
If you want to access the extra services this repository has to offer, click this link: <xsl:call-template name="ResourceExtractor"/>
                            </xsl:if>
                        </xsl:for-each>
                    <hr/>
                </xsl:for-each>
            </body>
        </html>
    </xsl:template>

    <xsl:template name="PersistentIdentifier">
        <xsl:value-of select="didl:Descriptor/didl:Statement/dii:Identifier"/>
    </xsl:template>

    <xsl:template name="ResourceExtractor">
	<ul>
        <xsl:for-each select="didl:Component/didl:Resource">
            <li><a>
                <xsl:attribute name="href">
                    <xsl:value-of select="attribute::ref"/>
                </xsl:attribute>
                <xsl:value-of select="attribute::ref"/>
            </a>; <br/></li>
            
        </xsl:for-each>
	</ul>
    </xsl:template>
    
    <xsl:template name="MetadataFormatter">
        <xsl:choose>
            <xsl:when test="didl:Component/didl:Resource/oai_dc:dc"
                xmlns="http://www.w3.org/2001/XMLSchema"
                xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
                xmlns:oai_dc="http://www.openarchives.org/OAI/2.0/oai_dc/"
                xmlns:dc="http://purl.org/dc/elements/1.1/"
                xsi:schemaLocation="
                http://www.openarchives.org/OAI/2.0/oai_dc/
                http://www.openarchives.org/OAI/2.0/oai_dc.xsd 
                http://purl.org/dc/elements/1.1/">
                <em>(in simple Dublin Core)</em><br/>
                <xsl:for-each select="didl:Component/didl:Resource/oai_dc:dc/dc:title">
                    <b>Title: </b><xsl:value-of select="self::dc:title"/><br/>
                </xsl:for-each>
                <b>Creator: </b>
                <xsl:for-each select="didl:Component/didl:Resource/oai_dc:dc/dc:creator">
                    <xsl:value-of select="self::dc:creator"/>, 
                </xsl:for-each><br/>
                <b>Date: </b>
                <xsl:for-each select="didl:Component/didl:Resource/oai_dc:dc/dc:date">
                    <xsl:value-of select="self::dc:date"/>; 
                </xsl:for-each><br/>
                <b>Description: </b>
                <xsl:for-each select="didl:Component/didl:Resource/oai_dc:dc/dc:description">
                    <xsl:value-of select="self::dc:description"/>; 
                </xsl:for-each><br/>
                <b>Subject: </b>
                <xsl:for-each select="didl:Component/didl:Resource/oai_dc:dc/dc:subject">
                    <xsl:value-of select="self::dc:subject"/>; 
                </xsl:for-each><br/>
                <b>Publisher: </b>
                <xsl:for-each select="didl:Component/didl:Resource/oai_dc:dc/dc:publisher">
                    <xsl:value-of select="self::dc:publisher"/>; 
                </xsl:for-each><br/>
                <b>Type: </b>
                <xsl:for-each select="didl:Component/didl:Resource/oai_dc:dc/dc:type">
                    <xsl:value-of select="self::dc:type"/>; 
                </xsl:for-each><br/>
            </xsl:when>
        </xsl:choose>
       
    </xsl:template>


</xsl:stylesheet>
